@@ -2,10 +2,11 @@ from starlette.applications import Starlette
 from starlette.middleware import Middleware
 from starlette.middleware.sessions import SessionMiddleware
 from starlette.middleware.authentication import AuthenticationMiddleware
+from starlette.authentication import AuthCredentials, AuthenticationBackend, AuthenticationError, SimpleUser, requires
 from starlette.middleware.httpsredirect import HTTPSRedirectMiddleware
 from starlette.middleware.trustedhost import TrustedHostMiddleware
 from starlette.responses import Response, HTMLResponse, FileResponse, JSONResponse
-from starlette.requests import Request
+from starlette.requests import Request, HTTPConnection
 from starlette.staticfiles import StaticFiles
 from starlette.exceptions import HTTPException
 from starlette._utils import is_async_callable
@@ -15,4 +16,5 @@ from starlette.exceptions import HTTPException,WebSocketException
 from starlette.endpoints import HTTPEndpoint,WebSocketEndpoint
 from starlette.config import Config
 from starlette.datastructures import CommaSeparatedStrings, Secret
+from starlette.types import ASGIApp, Receive, Scope, Send
 
